ListenableWidget<T extends ChangeNotifier> class
abstract
Properties
-
autoDispose
→ bool
-
Whether the widget should automatically dispose of the
viewModel.
no setter
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
key
→ Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
build(BuildContext context, T viewModel)
→ Widget
-
Builds the widget tree using the provided
viewModel.
This method is called whenever the viewModel notifies its listeners.
-
create(BuildContext context)
→ T
-
Creates and returns the
T instance.
This method is called once during the widget's initialization.
-
createElement()
→ StatefulElement
-
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState()
→ State<ListenableWidget<ChangeNotifier>>
-
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren()
→ List<DiagnosticsNode>
-
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(DiagnosticPropertiesBuilder properties)
→ void
-
Add additional properties associated with the node.
inherited
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
onDependenciesChanged(BuildContext context, T viewModel)
→ void
-
Called when the widget's dependencies change.
This can be used to refresh the
viewModel or perform any necessary updates.
-
onWidgetChanged(BuildContext context, ListenableWidget<T> oldWidget, T viewModel)
→ void
-
Called when the widget is updated with a new configuration.
This can be used to update the
viewModel or perform any necessary actions.
-
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style})
→ DiagnosticsNode
-
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString({DiagnosticLevel minLevel = DiagnosticLevel.info})
→ String
-
A string representation of this object.
inherited
-
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65})
→ String
-
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug})
→ String
-
Returns a one-line detailed description of the object.
inherited
-
toStringShort()
→ String
-
A short, textual description of this widget.
inherited